@@ -11,29 +11,39 @@ import requests
 from pydrive.auth import GoogleAuth
 from pydrive.drive import GoogleDrive
 from decouple import config
-
+from pybtex.database import BibliographyData, Entry
 
 apiKey = config('monday_apikey')
 apiUrl = "https://api.monday.com/v2"
 headers = {"Authorization": apiKey, "Content-Type ": "application/json"}
 
+
 @click.group()
-@click.command()
+def main():
+    pass
+
+
+@main.command()
 def cli():
     """Example script."""
     file_exists = exists(os.getcwd() + '/audit-dog.yml')
 
     if not file_exists:
-        with open('spec.yml', 'r') as f:
-            yaml_data = list(yaml.load_all(f, Loader=SafeLoader))
+        # with open('spec.yml', 'r') as f:
+        #     yaml_data = list(yaml.load_all(f, Loader=SafeLoader))
 
-        yml_data = [{'client': yaml_data[0]['client'], 'repo_name': yaml_data[0]['name'],
-                     'repo_description': yaml_data[0]['description']}]
-        with open('audit-dog.yml', 'w') as f:
-            data = yaml.dump(yml_data, f, sort_keys=False, default_flow_style=False)
-            print(data)
+        # yml_data = [{'client': yaml_data[0]['client'], 'repo_name': yaml_data[0]['name'],
+        #              'repo_description': yaml_data[0]['description'],'flag':'flat'}]
+        yml_data = [{'client': 'sigil', 'repo_name': 'AUDIT_DOG',
+                     'repo_description': 'An audit agent for policy compliance inspection across projects',
+                     'flag': 'flat'}]
+        CreateFileInRepo('audit-dog.yml', yml_data)
+        # with open('audit-dog.yml', 'w') as f:
+        #     data = yaml.dump(yml_data, f, sort_keys=False, default_flow_style=False)
+        #     print(data)
 
-@click.command()
+
+@main.command()
 def run():
     name = GetBoardFromGitlab()
     non_conformance_id = config('non_conformance_id')
@@ -102,6 +112,67 @@ def run():
                 except Exception as e:
                     print(e)
 
+
+@main.command()
+def seed():
+    file_exists = exists(os.getcwd() + '/spec.yml')
+    if not file_exists:
+        yml_data = [{'version': '0.2', 'privacy': 'confidential',
+                     'confidential': 'Study Protocol'}]
+        CreateFileInRepo('spec.yml', yml_data)
+
+    file_exists = exists(os.getcwd() + '/capabilities.yml')
+    if not file_exists:
+        yml_data = [{'name': 'audit dog', 'title': 'Audit Dog',
+                     'long': 'AuditDog'}]
+        CreateFileInRepo('capabilities.yml', yml_data)
+
+    file_exists = exists(os.getcwd() + '/env.yml')
+    if not file_exists:
+        yml_data = [{'name': 'audit dog', 'title': 'Audit Dog',
+                     'long': 'AuditDog'}]
+        CreateFileInRepo('env.yml', yml_data)
+
+    file_exists = exists(os.getcwd() + '/references.bib')
+    if not file_exists:
+        bib_data = BibliographyData({
+            'article-minimal': Entry('article', [
+                ('author', 'L[eslie] B. Lamport'),
+                ('title', 'The Gnats and Gnus Document Preparation System'),
+                ('journal', "G-Animal's Journal"),
+                ('year', '1986'),
+            ]),
+        })
+
+        bib_data.to_file(file='references.bib', bib_format='bibtex')
+
+    if not os.path.exists('assets'):
+        os.mkdir('assets')
+        print("Directory ", 'assets', " Created ")
+
+    file_exists = exists(os.getcwd() + '/README.yml')
+    if not file_exists:
+        yml_data = ['An audit agent for policy compliance inspection across projects and teams./n/n **Workinks** /n [Gitlab](https://gitlab.com/sigil-scientific-enterprises/audit-dog)']
+        CreateFileInRepo('env.yml', yml_data)
+
+    file_exists = exists(os.getcwd() + '/README.md')
+    if not file_exists:
+        yml_data = 'An audit agent for policy compliance inspection across projects and teams.\n\n **Workinks** \n\n [Gitlab](https://gitlab.com/sigil-scientific-enterprises/audit-dog)'
+        with open('README.md', 'w') as f:
+            f.write(yml_data)
+
+    """ spec.yml is creating.
+    capabilities.yml is creating.
+    env.yml is creating
+    references.yml is creating """
+
+
+def CreateFileInRepo(filename, yml_data):
+    with open(filename, 'w') as f:
+        data = yaml.dump(yml_data, f, sort_keys=False, default_flow_style=False)
+
+
+
 def GetBoardFromGitlab():  # for getting repository information
     logging.info('This is in GetBoardFromGitlab function')
     url = config('gitlab_url')
@@ -110,4 +181,4 @@ def GetBoardFromGitlab():  # for getting repository information
     r = requests.get(url=url, headers=headers1)
     jsondata = r.json()
     myBoardName = jsondata.get('name')
-    return myBoardName
\ No newline at end of file
+    return myBoardName
